<?xml version='1.0' encoding='gb2312'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:template match="/rss/channel">
		<html>
			<head>
				<title><xsl:value-of select='title'/></title>
				<style type="text/css">
					h1 {
						font-weight      : bold;
						margin           : 0px;
						margin-bottom    : 3px;
					}
					h3 {
						font-weight      : bold;
						margin           : 0px;
						margin-bottom    : 5px;
						border-bottom    : 1px dashed #CCCCCC;
					}
					body {
						color            : #000000;
						background-color : #FFFFFF;
						font-family      : Verdana, Geneva, Arial, Helvetica, sans-serif;
						margin           : 10px;
					}
					a:active, a:link {
						color            : #000066;
						text-decoration  : none;
					}
					a:visited {
						color            : #660066;
						text-decoration  : none;
					}
					a:hover {
						color            : #0000FF;
						text-decoration  : underline;
					}
					#category {
						padding          : 1px;
						border-bottom    : 1px solid black;
						margin-bottom    : 1px;
					}
					#header {
						padding          : 10px;
						border-bottom    : 1px solid #6666666;
						margin-bottom    : 1px;
					}
					#list {
						border-left      : 1px solid #CCCCCC;
						float            : right;
						width            : 230px;
						font-size        : 70%;
						padding          : 5px;
					}
					#list a:visited {
						color            : #000066;
					}
					#list a:hover {
						color            : #0000FF;
					}
					#list ul {
						color            : #666666;
						list-style       : square;
						margin           : 0px;
						margin-left      : 15px;
					}
					#content {
						margin-right     : 230px;
					}
					#copyright {
						margin-top       : 1px;
						margin-bottom    : 5px;
						padding-top      : 10px;
						border-top       : 1px solid black;
						font-size        : 80%;
					}
					.textbox {
						padding          : 10px;
					}
					.textbox2 {
						background-color : aliceblue;
						padding          : 10px;
					}
					.description {
						font-size        : 80%;
					}
					.description a:link,
					.description a:visited,
					.description a:active
					{
						text-decoration  : underline;
					}
					.title {
						padding-bottom   : 10px;
					}
					.label {
						font-size        : 70%;
						color            : #666666;
					}
					.go-top {
						font-size        : 70%;
					}
					.go-top a:visited {
						color            : #000066;
					}
<!--					.clear{
						clear: left;
					}-->
<!--					blockquote{
						background-color:#FEFEFE;
					}-->
				</style>
			</head>
			<body>
					<xsl:if test="count(category) &gt; 0">
					<div id="category">
						<xsl:for-each select="category">
							<xsl:value-of select='.' /> | 
						</xsl:for-each>
					</div>
				</xsl:if>
				<div id="header">
					<a href="{link}"><h1>
						<xsl:value-of select="title" disable-output-escaping='yes' />
					</h1></a>
					<xsl:if test="count(description) &gt; 0">
						<div class="label"><br/><xsl:value-of select="description"/></div>
					</xsl:if>
				</div>
				<div id="list">
					<xsl:if test="count(image/url) &gt; 0">
						<br/>
						<a href="{image/link}">
						<img border="0">
							<xsl:attribute name="src">
								<xsl:value-of select="image/url" />
							</xsl:attribute>
							<xsl:attribute name="alt">
								<xsl:value-of select="image/title" />
							</xsl:attribute>
						</img>
						</a>
						<br/><br/>
					</xsl:if>
					<ul>
					<xsl:for-each select="item">
					<xsl:if test="position() &lt; 101">
						<li><a href="#{position()}" title="{title}"><xsl:value-of select="title" disable-output-escaping='yes' /></a></li>
					</xsl:if>
					</xsl:for-each>
					</ul>
				</div>
				<div id="content">
					<xsl:for-each select="item">
					<xsl:if test="position() &lt; 101">
						<div class="textbox">
							<xsl:choose>
								<xsl:when test="position() mod 2 = 1">
									<xsl:attribute name="class">textbox</xsl:attribute>
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="class">textbox2</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<a name="{position()}"></a>
							<div class="title">
								<h3><xsl:choose>
									<xsl:when test="count(link) &gt; 0">
										<a href="{link}"><xsl:value-of select="title" disable-output-escaping='yes' /></a><br/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="title" disable-output-escaping='yes' /><br />
									</xsl:otherwise>
								</xsl:choose></h3>
								<div class="label">
									<xsl:value-of select="pubDate"/>
									<xsl:if test="count(author) &gt; 0">
										<xsl:text disable-output-escaping = "yes">&amp;nbsp;&amp;nbsp;&amp;nbsp;</xsl:text>
										<xsl:value-of select="author"/>
									</xsl:if>
									<xsl:if test="count(comments) &gt; 0">
										<xsl:text disable-output-escaping = "yes">&amp;nbsp;&amp;nbsp;&amp;nbsp;</xsl:text>
										<a style="align:right" href="{comments}"></a>
									</xsl:if>
								</div>
							</div>
							<div class="description"><xsl:value-of select="description" disable-output-escaping='yes' /></div>
							<div class="go-top" align="right"><a href="#">Top</a></div>
						</div>
					</xsl:if>
					</xsl:for-each>
				</div>
				<xsl:if test="count(copyright) &gt; 0">
					<div id="copyright" align="center"><xsl:value-of select="copyright" disable-output-escaping='yes' /></div>
				</xsl:if>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
